import type { Metadata } from "next";

import { ThemeProvider } from "./ui/theme";
import { Toaster } from "@/components/ui/toaster";
import "./globals.css";
import Navlinks from "./ui/navLinks";
import { ModeToggle } from "./ui/modeToggle";
import { inter } from "./ui/fonts";
import LogoutButton from "./ui/logoutButton";




export const metadata: Metadata = {
  title: "Subman",
  description: "A self-hosted literary submission tracker."
};


export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body className={inter.className}>
        <ThemeProvider
          attribute="class"
          defaultTheme="system"
          enableSystem
          disableTransitionOnChange
        >
          <div id="layout-container" className="md:p-4 w-screen h-screen mt-2 md:mt-6 flex justify-center">
            <div className="w-full md:w-5/6 flex flex-col md:flex-row">
              <div id="sidebar" className=" flex flex-row md:flex-col  justify-between items-center"> <header className="">
                <h1 className="font-black text-primary-foreground bg-primary antialiased w-full p-2 rounded-tl-3xl pl-6 pr-4 text-sm sm:text-4xl
                ">SubMan</h1>
                <p className="mt-2 mx-1 text-sm antialiased w-40 hidden md:block">The self-hosted literary submission tracker.</p>
              </header>
                <Navlinks className="md:mt-6" />
                <footer className="my-auto md:mt-auto flex justify-center"><ModeToggle /><LogoutButton />
                </footer>
              </div>
              <div className="flex justify-center w-full">
                {children}
              </div>
            </div>
          </div>
          <Toaster />
        </ThemeProvider>
      </body>
    </html >
  );
}
