import { z } from "zod";

export const storySchema = z.object({
	title: z.string().min(2).max(50),
	word_count: z.coerce.number(),
	genres: z.object({ id: z.number(), name: z.string() }).array()
})

export const pubSchema = z.object({
	id: z.coerce.number().optional(),
	title: z.string().min(2).max(50),
	link: z.string(),
	query_after_days: z.coerce.number().min(30),
	genres: z.array(z.number()),
})

export const subSchema = z.object({
	id: z.number().optional(),
	storyId: z.coerce.number(),
	pubId: z.coerce.number(),
	submitted: z.coerce.date().transform((date) => date.toString()),
	responded: z.coerce.date().transform((date) => {
		if (date.toString() !== new Date(null).toString()) {
			return date.toString()
		}
		return null
	}).optional(),
	responseId: z.coerce.number()
})
	.refine(object => {
		const submitted = new Date(object.submitted)
		const responded = object.responded ? new Date(object.responded) : null
		return responded >= submitted || responded === null
	},
		{
			path: ["responded"],
			message: "'Responded' must be a later date than 'submitted'"
		})
	.refine(object => {
		if (object.responded) {
			//there is a 'responded' date and the response is not 'pending'
			return object.responseId !== 7
		}
		if (!object.responded) {
			//there is not a 'responded' date and the response is pending
			return object.responseId === 7
		}
	},
		{
			path: ["responseId"],
			message: "A pending response cannot have a date, and a non-pending response must have a date"
		}
	)

